/*
 * Arduino 1 / POLULU
 * XBee Star : end device
 * ----------------------------------
 * XBee #1 is the coordinator (one sender)
 * XBee #2, #3, ... are end devices (multiple receivers)
 * Coordinator : ATRE, ATID1111, ATBD6, ATCE1, ATAP2, ATWR
 * End #2      : ATRE, ATID1111, ATBD6, ATMY2, ATAP2, ATWR
 * End #3      : ATRE, ATID1111, ATBD6, ATMY3, ATAP2, ATWR
 * ...
 *
 * Author: jeromeabel.net
 * Licence: GNU/GPL3
 * Date: 2014-09
 * Art project: http://jeromeabel.net/art/patatas-de-goma
 */
 
#include <Tone.h>
#include <XBee.h> 

// ---- XBEE ---- //
XBee xbee = XBee();
XBeeResponse response = XBeeResponse();
Rx16Response rx16 = Rx16Response();

// ---- PATATAS ---- //
Tone tone1;
int pinTone = 3; // Klaxon tone
int pinPwm = 9; // Klaxon intensity
int pinPhPwm = 5; // Phare

// 8Mhz/PeriodePWM = ... Hz
long periodePWM = 1000; //max duty cycle 


// ---- TIMER ---- //
// TIMER 0 : 5/6 (PHARE)
// TIMER 1 : 9/10 OCR1A/OCR1B (KLAXON / PWM : 10KHZ)
// TIMER 2 : 3/11 (TONE)
// !! TCCR2A error with Leonardo !! because of the Tone library

// ---- DATA ---- //
// data[0] = klaxon 1 tone
// data[1] = klaxon 1 pwm
// data[2] = klaxon 2 tone
// data[3] = klaxon 2 pwm
// data[4] = phare 1 
// data[5] = phare 2
// data[6] = periodePWM
int data0 = 0;
int lastdata0 = 0;
long data1 = 0;
long lastdata1 = 0;
int data2 = 0;
int lastdata2 = 0;
long data3 = 0;
long lastdata3 = 0;
int data4 = 0;
int lastdata4 = 0;
int data5 = 0;
int lastdata5 = 0;
long data6 = 0;
long lastdata6 = 0;

void setup() {
  // ENABLE
  pinMode(6,OUTPUT); // M1EN
  digitalWrite(6,HIGH);
  pinMode(12,OUTPUT); // M2EN
  digitalWrite(12,HIGH);
  pinMode(2,OUTPUT); // M1INA
  digitalWrite(2,HIGH);
  pinMode(7,OUTPUT); // M2INA
  digitalWrite(7,HIGH);
  
  // 16Mhz(horloge)/2/1(prescaler) : 8Mhz
  TCCR1A = 0b10100000;
  TCCR1B = 0b00010001;
  ICR1 = periodePWM; 
  
  // PINS
  pinMode(pinPwm, OUTPUT);
  pinMode(pinPhPwm, OUTPUT);   
  tone1.begin(pinTone);
  
  Serial.begin(57600);
  xbee.setSerial(Serial);
  
  digitalWrite(pinPhPwm,HIGH);
  delay(1000);
  digitalWrite(pinPhPwm,LOW);
}

void loop() {  
    xbee.readPacket();
    if (xbee.getResponse().isAvailable()) {
        if (xbee.getResponse().getApiId() == RX_16_RESPONSE) {
           xbee.getResponse().getRx16Response(rx16);
           
           // Get data
           data0 = rx16.getData(0);
           data1 = rx16.getData(1);
           data2 = rx16.getData(2);
           data3 = rx16.getData(3);
           data4 = rx16.getData(4);
           data5 = rx16.getData(5);
           data6 = rx16.getData(6);
           
           if (data0 != lastdata0 && data0 >= 0) {
             //Serial.print("data0 :");
             //Serial.println(data0 * 4);
             tone1.play(data0 * 4); // 255 * 4 = 1020Hz max
           }
           if (data1 != lastdata1 && data1 >= 0) {
             //Serial.print("data1 : ");
             //Serial.println(data1 * periodePWM * 0.01);
             OCR1A = data1 * periodePWM * 0.01;
           }
           if (data2 != lastdata2 && data2 >= 0) {
             Serial.print("kt ");
             Serial.println(data2);
           }
           if (data3 != lastdata3 && data3 >= 0) {
             Serial.print("kp ");
             Serial.println(data3);
           }
           if (data4 != lastdata4 && data4 >= 0) {
             analogWrite(pinPhPwm, data4);
           }
           if (data5 != lastdata5 && data5 >= 0) {
             Serial.print("ph ");
             Serial.println(data5);
           }
           if (data6 != lastdata6 && data6 >= 0) {
             periodePWM = data6 * 10;
             Serial.print("cy ");
             Serial.println(data6 * 10);
           }
           
           lastdata0 = data0;
           lastdata1 = data1;
           lastdata2 = data2;
           lastdata3 = data3;
           lastdata4 = data4;
           lastdata5 = data5;
           lastdata6 = data6;
         }
    }
}
